@@ -118,7 +118,7 @@ class options(ranaModule):
 
 
 
-    # network
+    # * network *
     self.addOption("Network", "network",
 #      [("off","No use of network"),
       [("minimal", "Only for important data"),
@@ -126,9 +126,24 @@ class options(ranaModule):
        "network",
        "full")
 
-    # gps
+    # * GPS *
     self.addBoolOption("GPS", "GPSEnabled", "GPS", True, "gpsd:checkGPSEnabled")
 
+    # * screen *
+    """only add if supported on device"""
+    display = self.m.get('display', None)
+    if display:
+      if display.screenBlankingControlSupported():
+        self.addOption("Keep display ON", "screenBlankingMode",
+        [("always", "always", "display:blankingModeChanged"),
+         ("moving", "while moving", "display:blankingModeChanged"),
+         ("movingInFullscreen", "while moving in fullscreen", "display:blankingModeChanged"),
+         ("fullscreen", "while in fullscreen", "display:blankingModeChanged"),
+         ("gpsFix", "while there is a GPS fix", "display:blankingModeChanged"), #TODO: while there is actually a GPS lock
+         ("never", "never", "display:blankingModeChanged")],
+         "Display",
+         "always")
+
 #    self.addOption("Network", "threadedDownload",
 ##      [("off","No use of network"),
 #      [("True", "Use threads for download"),
@@ -256,12 +271,12 @@ class options(ranaModule):
        "Navigation",
        "en en") # TODO: use locale for default language ?
 
-    self.addOption("Autostart navigation", "autostartNavigation",
+    self.addOption("Autostart navigation", "autostartNavigationDefaultOn",
       [('disabled',"Disabled"),
        ('first',"From first point"),
        ('closest',"From closest point")],
        "Navigation",
-       'disabled')
+       'closest')
 
     self.addOption("Point reached distance", "pointReachedDistance",
       [(10,"10 m"),
@@ -275,6 +290,12 @@ class options(ranaModule):
        "Navigation",
        30)
 
+    self.addOption("read Cyrillic with:", "voiceNavigationCyrillicVoice",
+      [('ru',"Russian voice"),
+       (None,"current voice")],
+       "Navigation",
+       'ru')
+
 
     # * POI
     self.addOption("POI database", "POIDBFilename",
